@@ -1,11 +1,13 @@
+import ast
 import html
 import inspect
 import multiprocessing as mp
 import re
 import sys
+import argparse
 import typing as t
+from argparse import Namespace
 from contextlib import contextmanager
-from functools import partial
 from io import StringIO
 from pathlib import Path
 from traceback import format_exception
@@ -15,12 +17,12 @@ import signal
 import docstring_parser as dp
 import pandas as pd
 import pyqtgraph as pg
-from pyqtgraph.Qt import QtWidgets, QtCore
+from pyqtgraph.Qt import QtWidgets, QtCore, QtGui
 from pyqtgraph.parametertree import Parameter, ParameterTree
 from tqdm import tqdm
 import cv2 as cv
 
-from .params.prjparam import PrjParam
+from .params import PrjParam
 from .typeoverloads import FilePath
 
 # -----
@@ -456,6 +458,83 @@ def getParamChild(param: Parameter, *childPath: t.Sequence[str], allowCreate=Tru
     param.setDefault(param.value())
   return param
 
+class ArgParseConverter(argparse.ArgumentParser):
+  """Able to convert arguments to their types on parse_args"""
+  convertRemainder = True
+
+  def parse_args(self, args=None, namespace=None):
+    def argConverter(arg):
+      try:
+        return ast.literal_eval(arg)
+      except:
+        return arg
+
+    namespace, args = super().parse_known_args(args, namespace)
+    # Treat remainder as if they belonged
+    named = vars(namespace)
+    if not self.convertRemainder:
+      return namespace
+    extraIter = list(args)
+    ii = 0
+    while ii < len(extraIter):
+      item = extraIter[ii]
+      if item.startswith('--'):
+        kk = item.strip('--')
+        try:
+          nextK = extraIter[ii + 1]
+          if nextK.startswith('--'):
+            # This is also a flag condition, don't consume value this round
+            vv = True
+          else:
+            vv = argConverter(nextK)
+            # Value consumed, move on an extra space
+            ii += 1
+        except IndexError:
+          vv = True
+        named[kk] = vv
+        ii += 1
+    return Namespace(**named)
+
+def makeCli(func: t.Callable, convertArgs=True, parserKwargs: dict=None, **procKwargs):
+  """
+  Creates a CLI interface to a function from the provided function, parsing the documentation for help text, signature
+  for default values, etc.
+
+  :param func: Function from which to make a CLI interface
+  :param convertArgs: Whether to use a parser which converts string cli arguments to python values
+  :param parserKwargs: Passed to ArgumentParser on init
+  :param procKwargs: Passed to AtomicProcess which is used as an intermediate to generate parameter documentation
+  """
+  from .params import NestedProcWrapper
+  from .processing import AtomicProcess
+  def tipConverter(inStr):
+    doc = QtGui.QTextDocument()
+    doc.setHtml(inStr)
+    return doc.toPlainText()
+
+  proc = AtomicProcess(func, **procKwargs)
+  param = NestedProcWrapper(proc).parentParam
+
+  useCls = argparse.ArgumentParser if not convertArgs else ArgParseConverter
+  parserKwargs = parserKwargs or {}
+  parserKwargs.update(description=tipConverter(param.opts['tip']))
+  parser = useCls(**parserKwargs)
+
+  for ch in param:
+    if 'action' not in ch.type():
+      ch: Parameter
+      arg = parser.add_argument(f'--{ch.name()}',
+      type=type(ch.value()))
+      if ch.hasDefault():
+        arg.default = ch.defaultValue()
+      if 'tip' in ch.opts:
+        arg.help = tipConverter(ch.opts['tip'])
+  # if proc.hasKwargs:
+  #   sig = inspect.signature(func)
+  #   kwParam = [name for name, par in sig.parameters.items() if par.kind is par.VAR_KEYWORD][0]
+  #   parser.add_argument(f'--{kwParam}', nargs=argparse.REMAINDER, dest=argparse.SUPPRESS)
+  return parser
+
 
 def dialogGetSaveFileName(parent, winTitle, defaultTxt: str=None)-> t.Optional[str]:
   failedSave = True
