@@ -698,12 +698,12 @@ class ParamEditor(QtWidgets.QDockWidget):
 
   def _mkMetaTree(self):
     self._metaParamGrp = Parameter.create(name='Meta Parameters', type='group')
-    self._metaTree = fns.flexibleParamTree(self._metaParamGrp, showTop=False)
+    mt = self._metaTree = fns.flexibleParamTree(self._metaParamGrp, showTop=False)
     """
     Tree for controlling meta-parameters, useful for configuring the parameter editor itself
     (i.e. loading state, etc.)
     """
-    # self._metaTree.setSizePolicy(self._metaTree.sizePolicy().horizontalPolicy(), QtWidgets.QSizePolicy.Fixed)
+    self._metaParamGrp.sigChildAdded.connect(lambda: mt.setMinimumHeight(int(mt.sizeHint().height()*1.1)))
     return self._metaTree, self._metaParamGrp
 
   def __repr__(self):
