@@ -112,7 +112,8 @@ class ParamEditorPlugin(pe.EditorPropsMixin):
     returnParam = kwargs.get('returnParam', False)
     if returnParam:
       proc, param = proc
-    act = parentMenu.addAction(proc.name)
+    if parentMenu is not None:
+      act = parentMenu.addAction(proc.name)
     if ShortcutParameter.REGISTRY and shcValue and self._makeMenuShortcuts:
       ShortcutParameter.REGISTRY.registerAction(opts, act,
                                                 namePath=(owner.__groupingName__,))
@@ -148,7 +149,8 @@ class ParamEditorPlugin(pe.EditorPropsMixin):
 
   def attachWinRef(self, win):
     self.win = win
-    self.menu.setParent(self.parentMenu, self.menu.windowFlags())
+    if self.menu is not None and self.parentMenu is not None:
+      self.menu.setParent(self.parentMenu, self.menu.windowFlags())
     for proc in self.toolsEditor.procToParamsMapping:
       proc.updateInput(win=win)
     if self.dock:
@@ -165,7 +167,8 @@ class ParamEditorPlugin(pe.EditorPropsMixin):
       btn.addMenu = btn.setMenu
       btn.addAction = lambda act: act.triggered.connect(btn.click)
       btn.setPopupMode(btn.InstantPopup)
-    parentToolbarOrMenu.addMenu(self.menu)
+    if self.menu is not None:
+      parentToolbarOrMenu.addMenu(self.menu)
 
 def dockPluginFactory(name_: str=None, editors: Sequence[pe.ParamEditor]=None):
   class DummyPlugin(ParamEditorPlugin):
